==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkThreshold.java <==
// java wrapper for vtkThreshold object
//

package vtk;
import vtk.*;

public class vtkThreshold extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ThresholdByLower_2(double id0);
  public void ThresholdByLower(double id0)
    { ThresholdByLower_2(id0); }

  private native void ThresholdByUpper_3(double id0);
  public void ThresholdByUpper(double id0)
    { ThresholdByUpper_3(id0); }

  private native void ThresholdBetween_4(double id0,double id1);
  public void ThresholdBetween(double id0,double id1)
    { ThresholdBetween_4(id0,id1); }

  private native double GetUpperThreshold_5();
  public double GetUpperThreshold()
    { return GetUpperThreshold_5(); }

  private native double GetLowerThreshold_6();
  public double GetLowerThreshold()
    { return GetLowerThreshold_6(); }

  private native void SetAttributeMode_7(int id0);
  public void SetAttributeMode(int id0)
    { SetAttributeMode_7(id0); }

  private native int GetAttributeMode_8();
  public int GetAttributeMode()
    { return GetAttributeMode_8(); }

  private native void SetAttributeModeToDefault_9();
  public void SetAttributeModeToDefault()
    { SetAttributeModeToDefault_9(); }

  private native void SetAttributeModeToUsePointData_10();
  public void SetAttributeModeToUsePointData()
    { SetAttributeModeToUsePointData_10(); }

  private native void SetAttributeModeToUseCellData_11();
  public void SetAttributeModeToUseCellData()
    { SetAttributeModeToUseCellData_11(); }

  private native String GetAttributeModeAsString_12();
  public String GetAttributeModeAsString()
    { return GetAttributeModeAsString_12(); }

  private native void SetComponentMode_13(int id0);
  public void SetComponentMode(int id0)
    { SetComponentMode_13(id0); }

  private native int GetComponentModeMinValue_14();
  public int GetComponentModeMinValue()
    { return GetComponentModeMinValue_14(); }

  private native int GetComponentModeMaxValue_15();
  public int GetComponentModeMaxValue()
    { return GetComponentModeMaxValue_15(); }

  private native int GetComponentMode_16();
  public int GetComponentMode()
    { return GetComponentMode_16(); }

  private native void SetComponentModeToUseSelected_17();
  public void SetComponentModeToUseSelected()
    { SetComponentModeToUseSelected_17(); }

  private native void SetComponentModeToUseAll_18();
  public void SetComponentModeToUseAll()
    { SetComponentModeToUseAll_18(); }

  private native void SetComponentModeToUseAny_19();
  public void SetComponentModeToUseAny()
    { SetComponentModeToUseAny_19(); }

  private native String GetComponentModeAsString_20();
  public String GetComponentModeAsString()
    { return GetComponentModeAsString_20(); }

  private native void SetSelectedComponent_21(int id0);
  public void SetSelectedComponent(int id0)
    { SetSelectedComponent_21(id0); }

  private native int GetSelectedComponentMinValue_22();
  public int GetSelectedComponentMinValue()
    { return GetSelectedComponentMinValue_22(); }

  private native int GetSelectedComponentMaxValue_23();
  public int GetSelectedComponentMaxValue()
    { return GetSelectedComponentMaxValue_23(); }

  private native int GetSelectedComponent_24();
  public int GetSelectedComponent()
    { return GetSelectedComponent_24(); }

  private native void SetAllScalars_25(int id0);
  public void SetAllScalars(int id0)
    { SetAllScalars_25(id0); }

  private native int GetAllScalars_26();
  public int GetAllScalars()
    { return GetAllScalars_26(); }

  private native void AllScalarsOn_27();
  public void AllScalarsOn()
    { AllScalarsOn_27(); }

  private native void AllScalarsOff_28();
  public void AllScalarsOff()
    { AllScalarsOff_28(); }

  private native void SetUseContinuousCellRange_29(int id0);
  public void SetUseContinuousCellRange(int id0)
    { SetUseContinuousCellRange_29(id0); }

  private native int GetUseContinuousCellRange_30();
  public int GetUseContinuousCellRange()
    { return GetUseContinuousCellRange_30(); }

  private native void UseContinuousCellRangeOn_31();
  public void UseContinuousCellRangeOn()
    { UseContinuousCellRangeOn_31(); }

  private native void UseContinuousCellRangeOff_32();
  public void UseContinuousCellRangeOff()
    { UseContinuousCellRangeOff_32(); }

  private native void SetPointsDataTypeToDouble_33();
  public void SetPointsDataTypeToDouble()
    { SetPointsDataTypeToDouble_33(); }

  private native void SetPointsDataTypeToFloat_34();
  public void SetPointsDataTypeToFloat()
    { SetPointsDataTypeToFloat_34(); }

  private native void SetPointsDataType_35(int id0);
  public void SetPointsDataType(int id0)
    { SetPointsDataType_35(id0); }

  private native int GetPointsDataType_36();
  public int GetPointsDataType()
    { return GetPointsDataType_36(); }

  private native void SetOutputPointsPrecision_37(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_37(id0); }

  private native int GetOutputPointsPrecision_38();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_38(); }

  public vtkThreshold() { super(); }

  public vtkThreshold(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-armv6h.pkg.tar.xz: vtk/vtkThreshold.java <==
// java wrapper for vtkThreshold object
//

package vtk;
import vtk.*;

public class vtkThreshold extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ThresholdByLower_2(double id0);
  public void ThresholdByLower(double id0)
    { ThresholdByLower_2(id0); }

  private native void ThresholdByUpper_3(double id0);
  public void ThresholdByUpper(double id0)
    { ThresholdByUpper_3(id0); }

  private native void ThresholdBetween_4(double id0,double id1);
  public void ThresholdBetween(double id0,double id1)
    { ThresholdBetween_4(id0,id1); }

  private native double GetUpperThreshold_5();
  public double GetUpperThreshold()
    { return GetUpperThreshold_5(); }

  private native double GetLowerThreshold_6();
  public double GetLowerThreshold()
    { return GetLowerThreshold_6(); }

  private native void SetAttributeMode_7(int id0);
  public void SetAttributeMode(int id0)
    { SetAttributeMode_7(id0); }

  private native int GetAttributeMode_8();
  public int GetAttributeMode()
    { return GetAttributeMode_8(); }

  private native void SetAttributeModeToDefault_9();
  public void SetAttributeModeToDefault()
    { SetAttributeModeToDefault_9(); }

  private native void SetAttributeModeToUsePointData_10();
  public void SetAttributeModeToUsePointData()
    { SetAttributeModeToUsePointData_10(); }

  private native void SetAttributeModeToUseCellData_11();
  public void SetAttributeModeToUseCellData()
    { SetAttributeModeToUseCellData_11(); }

  private native String GetAttributeModeAsString_12();
  public String GetAttributeModeAsString()
    { return GetAttributeModeAsString_12(); }

  private native void SetComponentMode_13(int id0);
  public void SetComponentMode(int id0)
    { SetComponentMode_13(id0); }

  private native int GetComponentModeMinValue_14();
  public int GetComponentModeMinValue()
    { return GetComponentModeMinValue_14(); }

  private native int GetComponentModeMaxValue_15();
  public int GetComponentModeMaxValue()
    { return GetComponentModeMaxValue_15(); }

  private native int GetComponentMode_16();
  public int GetComponentMode()
    { return GetComponentMode_16(); }

  private native void SetComponentModeToUseSelected_17();
  public void SetComponentModeToUseSelected()
    { SetComponentModeToUseSelected_17(); }

  private native void SetComponentModeToUseAll_18();
  public void SetComponentModeToUseAll()
    { SetComponentModeToUseAll_18(); }

  private native void SetComponentModeToUseAny_19();
  public void SetComponentModeToUseAny()
    { SetComponentModeToUseAny_19(); }

  private native String GetComponentModeAsString_20();
  public String GetComponentModeAsString()
    { return GetComponentModeAsString_20(); }

  private native void SetSelectedComponent_21(int id0);
  public void SetSelectedComponent(int id0)
    { SetSelectedComponent_21(id0); }

  private native int GetSelectedComponentMinValue_22();
  public int GetSelectedComponentMinValue()
    { return GetSelectedComponentMinValue_22(); }

  private native int GetSelectedComponentMaxValue_23();
  public int GetSelectedComponentMaxValue()
    { return GetSelectedComponentMaxValue_23(); }

  private native int GetSelectedComponent_24();
  public int GetSelectedComponent()
    { return GetSelectedComponent_24(); }

  private native void SetAllScalars_25(int id0);
  public void SetAllScalars(int id0)
    { SetAllScalars_25(id0); }

  private native int GetAllScalars_26();
  public int GetAllScalars()
    { return GetAllScalars_26(); }

  private native void AllScalarsOn_27();
  public void AllScalarsOn()
    { AllScalarsOn_27(); }

  private native void AllScalarsOff_28();
  public void AllScalarsOff()
    { AllScalarsOff_28(); }

  private native void SetUseContinuousCellRange_29(int id0);
  public void SetUseContinuousCellRange(int id0)
    { SetUseContinuousCellRange_29(id0); }

  private native int GetUseContinuousCellRange_30();
  public int GetUseContinuousCellRange()
    { return GetUseContinuousCellRange_30(); }

  private native void UseContinuousCellRangeOn_31();
  public void UseContinuousCellRangeOn()
    { UseContinuousCellRangeOn_31(); }

  private native void UseContinuousCellRangeOff_32();
  public void UseContinuousCellRangeOff()
    { UseContinuousCellRangeOff_32(); }

  private native void SetPointsDataTypeToDouble_33();
  public void SetPointsDataTypeToDouble()
    { SetPointsDataTypeToDouble_33(); }

  private native void SetPointsDataTypeToFloat_34();
  public void SetPointsDataTypeToFloat()
    { SetPointsDataTypeToFloat_34(); }

  private native void SetPointsDataType_35(int id0);
  public void SetPointsDataType(int id0)
    { SetPointsDataType_35(id0); }

  private native int GetPointsDataType_36();
  public int GetPointsDataType()
    { return GetPointsDataType_36(); }

  private native void SetInvert_37(boolean id0);
  public void SetInvert(boolean id0)
    { SetInvert_37(id0); }

  private native boolean GetInvert_38();
  public boolean GetInvert()
    { return GetInvert_38(); }

  private native void InvertOn_39();
  public void InvertOn()
    { InvertOn_39(); }

  private native void InvertOff_40();
  public void InvertOff()
    { InvertOff_40(); }

  private native void SetOutputPointsPrecision_41(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_41(id0); }

  private native int GetOutputPointsPrecision_42();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_42(); }

  public vtkThreshold() { super(); }

  public vtkThreshold(long id) { super(id); }
  public native long   VTKInit();

}
